dm: core: Rename ofnode_get_property_by_prop()

The current name is quite unwieldy. Change it to use an ofprop_ prefix
and shorten it. Fix the return-value comment while we are here.

Signed-off-by: Simon Glass <sjg@chromium.org>
diff --git a/include/dm/ofnode.h b/include/dm/ofnode.h
index d477ef1..9dcc1fe 100644
--- a/include/dm/ofnode.h
+++ b/include/dm/ofnode.h
@@ -802,7 +802,7 @@
  * ofnode_first_property()- get the reference of the first property
  *
  * Get reference to the first property of the node, it is used to iterate
- * and read all the property with ofnode_get_property_by_prop().
+ * and read all the property with ofprop_get_property().
  *
  * @node: node to read
  * @prop: place to put argument reference
@@ -814,7 +814,7 @@
  * ofnode_next_property() - get the reference of the next property
  *
  * Get reference to the next property of the node, it is used to iterate
- * and read all the property with ofnode_get_property_by_prop().
+ * and read all the property with ofprop_get_property().
  *
  * @prop: reference of current argument and place to put reference of next one
  * Return: 0 if OK, -ve on error. -FDT_ERR_NOTFOUND if not found
@@ -822,17 +822,17 @@
 int ofnode_next_property(struct ofprop *prop);
 
 /**
  * ofnode_get_property_by_prop() - get a pointer to the value of a property
  *
  * Get value for the property identified by the provided reference.
  *
  * @prop: reference on property
  * @propname: If non-NULL, place to property name on success,
- * @lenp: If non-NULL, place to put length on success
- * Return: 0 if OK, -ve on error. -FDT_ERR_NOTFOUND if not found
+ * @lenp: If non-NULL, place to put length on success, or error code on failure
+ * Return: pointer to property, or NULL if not found
  */
-const void *ofnode_get_property_by_prop(const struct ofprop *prop,
-					const char **propname, int *lenp);
+const void *ofprop_get_property(const struct ofprop *prop,
+				const char **propname, int *lenp);
 
 /**
  * ofnode_is_available() - check if a node is marked available
@@ -822,17 +822,17 @@
 
 /**
- * ofnode_get_property_by_prop() - get a pointer to the value of a property
+ * ofprop_get_property() - get a pointer to the value of a property
  *
  * Get value for the property identified by the provided reference.